{% extends "base.html" %}

{% set title = "Riego - Ventilboxen" %}
{% set active_menu = "boxes" %}


{% block content %}
<h1>Edit: {{ item['name'] }}</h1>
<form action="{{url('boxes_item_edit', item_id=item['id']) }}" method="POST"
      enctype="multipart/form-data">


      <div class="mb-3">
        <label for="id2" class="form-label">Name</label>
        <input id="id2" name="name" value="{{item['name']}}"  type="text" class="form-control">
      </div>



      <div class="mb-3">
        <label for="id4" class="form-label">topic</label>
        <input id="id4" name="remark" value="{{item['topic']}}"  type="text" class="form-control">
      </div>


      <div class="mb-3">
        <label for="id5" class="form-label">hostname</label>
        <input id="id5" name="remark" value="{{item['hostname']}}"  type="text" class="form-control">
      </div>



  <input type="submit">
</form>
<hr>

<p>
    <a href="{{url('boxes')}}">list</a>
    <a href="{{url('boxes_item_view', item_id=item['id']) }}">view</a>
    <a href="{{url('boxes_item_delete', item_id=item['id']) }}">delete</a>
</p>
{% endblock %}
